@@ -1,5 +1,3 @@
-context("tests use_favicon")
-
 test_that("test use_favicon",{
   with_dir(pkg,{
     use_favicon()
@@ -33,7 +31,9 @@ test_that("test use_favicon online fail",{
   with_dir(pkg,{
     golem::remove_favicon()
     expect_false(file.exists("inst/app/www/favicon.ico"))
+    if (getRversion() >= "3.5"){
     expect_error(use_favicon(path = "https://fr.wikipedia.org//static/favicon/dontexist.ico"))
+    }
     expect_false(file.exists("inst/app/www/favicon.ico"))
   })
 })
